pub struct AVSubtitle { /* private fields */ }Implementations
Sourceimpl AVSubtitle
impl AVSubtitle
pub fn as_ptr(&self) -> *const AVSubtitle
pub fn as_mut_ptr(&mut self) -> *mut AVSubtitle
Sourcepub unsafe fn set_ptr(&mut self, ptr: NonNull<AVSubtitle>)
pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVSubtitle>)
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
Sourcepub unsafe fn from_raw(raw: NonNull<AVSubtitle>) -> Self
pub unsafe fn from_raw(raw: NonNull<AVSubtitle>) -> Self
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
pub fn into_raw(self) -> NonNull<AVSubtitle>
Sourceimpl AVSubtitle
impl AVSubtitle
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new AVSubtitle.