pub struct AVSubtitleMut<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AVSubtitleMut<'a>
impl<'a> AVSubtitleMut<'a>
Sourcepub unsafe fn from_raw(raw: NonNull<AVSubtitle>) -> Self
pub unsafe fn from_raw(raw: NonNull<AVSubtitle>) -> Self
Safety
This function should only be called when raw is valid and can
be dropped. Please ensure its lifetime when used.
Methods from Deref<Target = AVSubtitle>
pub fn as_ptr(&self) -> *const AVSubtitle
pub fn as_mut_ptr(&mut self) -> *mut AVSubtitle
Sourcepub unsafe fn set_ptr(&mut self, ptr: NonNull<AVSubtitle>)
pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVSubtitle>)
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.