Module avutil

Module avutil 

Everything related to libavutil.

Structs

AVAudioFifo
Context for an Audio FIFO Buffer.
AVBufferRef
AVChannelLayout
AVChannelLayoutIter
Iterate over all standard channel layouts.
AVChannelLayoutRef
AVComponentDescriptor
AVDictionary
AVDictionaryEntry
AVDictionaryEntryMut
AVDictionaryEntryRef
AVDictionaryIter
Iterator over AVDictionary by reference.
AVDictionaryMut
AVDictionaryRef
AVFrame
AVFrameSideData
AVFrameSideDataRef
AVFrameWithImage
It’s a AVFrame bound with AVImage, the AVFrame references the buffer owned by the AVImage.
AVHWDeviceContext
AVHWDeviceTypeIter
Iterator over supported device types.
AVHWFramesContext
This struct describes a set or pool of “hardware” frames (i.e. those with data not located in normal system memory). All the frames in the pool are assumed to be allocated in the same way and interchangeable.
AVHWFramesContextMut
AVHWFramesContextRef
AVImage
AVMD5
AVMediaType
non exhaustive wrapper of AVMediaType
AVMem
AVMmap
A read-only file buffer, the file is mmaped when available.
AVPixFmtDescriptorRef
Descriptor that unambiguously describes how the bits of a pixel are stored in the up to 4 data planes of an image. It also stores the subsampling factors and number of components.
AVRational
Rational number (pair of numerator and denominator).
AVSamples
AvVersion
Version information decoded from av*_version()

Constants

FFMPEG_VERSION
The informative version string of the FFmpeg that ffi bindings were generated against.
VERSION
Descriptive semver version of the libavutil that ffi bindings were generated against.

Functions

av_add_q
Add two rationals. Returns b+c.
av_cmp_q
Compare two rationals.
av_d2q
Convert a double precision floating point number to a rational. In case of infinity, the returned value is expressed as {1, 0} or {-1, 0} depending on the sign.
av_div_q
Divide one rational by another. Returns b/c.
av_gcd_q
Return the best rational so that a and b are multiple of it. If the resulting denominator is larger than max_den, return def.
av_image_fill_arrays
Setup the data pointers and linesizes based on the specified image parameters and the provided array.
av_inv_q
Invert a rational. @param q value @return 1 / q
av_make_q
Create an AVRational.
av_mul_q
Multiply two rationals. Returns b*c.
av_nearer_q
Find which of the two rationals is closer to another rational.
av_q2d
Convert an AVRational to a double. @param a AVRational to convert @return a in floating-point form @see av_d2q()
av_q2intfloat
Convert an AVRational to a IEEE 32-bit float expressed in fixed-point format.
av_rescale_q
Rescale a 64-bit integer by 2 rational numbers.
av_rescale_q_rnd
Rescale a 64-bit integer by 2 rational numbers with specified rounding.
av_rescale_rnd
Rescale a 64-bit integer with specified rounding.
av_sub_q
Subtract one rational from another. Returns b-c.
configuration
Returns the configuration of the libavutil that has been linked (whether static or dynamic).
err2str
Return a description of the AVERROR code errnum.
get_bytes_per_sample
Return number of bytes per sample, return None when sample format is unknown.
get_media_type_string
Return a string describing the media_type enum, NULL if media_type is unknown.
get_packed_sample_fmt
Get the packed alternative form of the given sample format, return None on error.
get_pix_fmt_name
Return the name of the given pixel format, or None if pix_fmt is not recognized.
get_planar_sample_fmt
Get the planar alternative form of the given sample format. return None on error.
get_sample_fmt
Return a sample format corresponding to name, or None on error.
get_sample_fmt_name
Return the name of given sample_fmt, or None if sample_fmt is not recognized.
hwdevice_find_type_by_name
Look up an AVHWDeviceType by name.
hwdevice_get_type_name
Get the string name of an AVHWDeviceType.
hwdevice_iterate_types
Iterate over supported device types.
license
Returns the license of the libavutil that has been linked (whether static or dynamic).
opt_set
name: the name of the field to setval: if the field is not of a string type, then the given string is parsed. SI postfixes and some named scalars are supported. If the field is of a numeric type, it has to be a numeric or named scalar. Behavior with more than one scalar and +- infix operators is undefined. If the field is of a flags type, it has to be a sequence of numeric scalars or named flags separated by ‘+’ or ‘-’. Prefixing a flag with ‘+’ causes it to be set without affecting the other flags; similarly, ‘-’ unsets a flag. If the field is of a dictionary type, it has to be a ‘:’ separated list of key=value parameters. Values containing ‘:’ special characters must be escaped.search_flags: flags passed to av_opt_find2. I.e. if `AV_OPT_SEARCH_CHILDREN`` is passed here, then the option may be set on a child of obj.
opt_set_bin
Note: if val.len() exceeds i32::MAX, this function returns [RsmpegError::TryFromIntError].
opt_set_double
Safety
opt_set_image_size
Safety
opt_set_int
Safety
opt_set_pixel_fmt
Safety
opt_set_q
Safety
opt_set_sample_fmt
Safety
opt_set_video_rate
Safety
ra
return AVRational: num / den;
sample_fmt_is_planar
Check if the sample format is planar.
ts2str
Get a string containing a timestamp representation.
ts2timestr
Get a string containing a timestamp time representation.
version
Returns the semver version of the libavutil that has been linked (whether static or dynamic).
version_info
Return an informative version string of the FFmpeg that has been linked (whether static or dynamic).

Type Aliases

AVHWDeviceType
AVMotionVector
AVPixelFormat
Pixel format.
AVRounding
Rounding methods.
AVSampleFormat
Audio sample formats