pub fn get_sample_fmt(name: &CStr) -> Option<AVSampleFormat>Expand description
Return a sample format corresponding to name, or None on error.
assert_eq!(
Some(AV_SAMPLE_FMT_FLT),
get_sample_fmt(&CString::new("flt").unwrap())
);pub fn get_sample_fmt(name: &CStr) -> Option<AVSampleFormat>Return a sample format corresponding to name, or None on error.
assert_eq!(
Some(AV_SAMPLE_FMT_FLT),
get_sample_fmt(&CString::new("flt").unwrap())
);