AVBufferRef

Struct AVBufferRef 

pub struct AVBufferRef { /* private fields */ }

Implementations

Source

impl AVBufferRef

pub fn as_ptr(&self) -> *const AVBufferRef

pub fn as_mut_ptr(&mut self) -> *mut AVBufferRef

pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVBufferRef>)

Safety

This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.

pub unsafe fn from_raw(raw: NonNull<AVBufferRef>) -> Self

Safety

This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.

pub fn into_raw(self) -> NonNull<AVBufferRef>

Source

impl AVBufferRef

pub fn new(size: usize) -> Self

Allocate an AVBuffer of the given size using av_malloc().

pub fn zeroed(size: usize) -> Self

Same as Self::new(), except the returned buffer will be initialized to zero.

pub fn realloc(&mut self, size: usize)

Reallocate a given buffer.

buf will be unreferenced and a new reference with the required size will be written in its place.

pub fn is_writable(&self) -> bool

Return true if the caller may write to the data referred to by buf (which is true if and only if buf is the only reference to the underlying AVBuffer). Return 0 otherwise.

pub fn get_ref_count(&self) -> c_int

Get ref count of current AVBuffer.

pub fn make_writable(&mut self)

Create a writable reference from a given buffer reference, avoiding data copy if possible.

self is either left untouched, or it is unreferenced and turned into new writable AVBufferRef.