pub struct AVDictionaryEntry { /* private fields */ }Implementations
Sourceimpl AVDictionaryEntry
impl AVDictionaryEntry
pub fn as_ptr(&self) -> *const AVDictionaryEntry
pub fn as_mut_ptr(&mut self) -> *mut AVDictionaryEntry
Sourcepub unsafe fn set_ptr(&mut self, ptr: NonNull<AVDictionaryEntry>)
pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVDictionaryEntry>)
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
Sourcepub unsafe fn from_raw(raw: NonNull<AVDictionaryEntry>) -> Self
pub unsafe fn from_raw(raw: NonNull<AVDictionaryEntry>) -> Self
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
pub fn into_raw(self) -> NonNull<AVDictionaryEntry>