AVDictionaryMut

Struct AVDictionaryMut 

pub struct AVDictionaryMut<'a> { /* private fields */ }

Implementations

Source

impl<'a> AVDictionaryMut<'a>

pub unsafe fn from_raw(raw: NonNull<AVDictionary>) -> Self

Safety

This function should only be called when raw is valid and can be dropped. Please ensure its lifetime when used.

Methods from Deref<Target = AVDictionary>

pub fn as_ptr(&self) -> *const AVDictionary

pub fn as_mut_ptr(&mut self) -> *mut AVDictionary

pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVDictionary>)

Safety

This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.

pub fn get_string(&self, key_val_sep: u8, pairs_sep: u8) -> Result<CString>

Get dictionary entries as a string.

Create a string containing dictionary’s entries. Such string may be passed back to Self::parse_string().

pub fn get( &'dict self, key: &CStr, prev: Option<AVDictionaryEntryRef<'_>>, flags: u32, ) -> Option<AVDictionaryEntryRef<'dict>>

Get a dictionary entry with matching key.

The returned entry key or value must not be changed, or it will cause undefined behavior.

To iterate through all the dictionary entries, you can set the matching key to the null string “” and set the AV_DICT_IGNORE_SUFFIX flag.

pub fn iter(&'dict self) -> AVDictionaryIter<'dict>

Iterates through all entries in the dictionary by reference.