pub struct AVFrameSideData { /* private fields */ }Implementations
Sourceimpl AVFrameSideData
impl AVFrameSideData
pub fn as_ptr(&self) -> *const AVFrameSideData
pub fn as_mut_ptr(&mut self) -> *mut AVFrameSideData
Sourcepub unsafe fn set_ptr(&mut self, ptr: NonNull<AVFrameSideData>)
pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVFrameSideData>)
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
Sourcepub unsafe fn from_raw(raw: NonNull<AVFrameSideData>) -> Self
pub unsafe fn from_raw(raw: NonNull<AVFrameSideData>) -> Self
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
pub fn into_raw(self) -> NonNull<AVFrameSideData>