Module swresample

Module swresample 

Everything related to libswresample.

Structs

SwrContext

Constants

VERSION
Descriptive semver version of the libswresample that ffi bindings were generated against.

Functions

configuration
Returns the configuration of the libswresample that has been linked (whether static or dynamic).
license
Returns the license of the libswresample that has been linked (whether static or dynamic).
version
Returns the semver version of the libswresample that has been linked (whether static or dynamic).