version

Function version 

pub fn version() -> AvVersion
Returns the semver version of the libswscale that has been linked (whether static or dynamic).

NOTE: This is not the same as the version of FFmpeg, see crate::avutil::version_info.

Examples

use rsmpeg::swscale;

let version = swscale::version();
assert_ne!(version.to_av_int(), 0);
// prints e.g. "59.39.100"
println!("{version}");