pub struct AVCodecParametersMut<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AVCodecParametersMut<'a>
impl<'a> AVCodecParametersMut<'a>
Sourcepub unsafe fn from_raw(raw: NonNull<AVCodecParameters>) -> Self
pub unsafe fn from_raw(raw: NonNull<AVCodecParameters>) -> Self
Safety
This function should only be called when raw is valid and can
be dropped. Please ensure its lifetime when used.
Methods from Deref<Target = AVCodecParameters>
pub fn as_ptr(&self) -> *const AVCodecParameters
pub fn as_mut_ptr(&mut self) -> *mut AVCodecParameters
Sourcepub unsafe fn set_ptr(&mut self, ptr: NonNull<AVCodecParameters>)
pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVCodecParameters>)
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
Sourcepub fn from_context(&mut self, context: &AVCodecContext)
pub fn from_context(&mut self, context: &AVCodecContext)
Fill current codecpar based on the values from the supplied
AVCodecContext. Any allocated fields in this codecpar are freed and
replaced with duplicates of the corresponding fields in codec.
Sourcepub fn copy(&mut self, from: &Self)
pub fn copy(&mut self, from: &Self)
Copy the contents from another AVCodecParameters. Any allocated fields in dst are freed
and replaced with newly allocated duplicates of the corresponding fields
in src.
Sourcepub fn codec_type(&self) -> AVMediaType
pub fn codec_type(&self) -> AVMediaType
Get the codec type.
Sourcepub fn ch_layout(&self) -> AVChannelLayoutRef<'_>
pub fn ch_layout(&self) -> AVChannelLayoutRef<'_>
Get channel layout