pub struct AVStreamMut<'a> { /* private fields */ }Implementations
Methods from Deref<Target = AVStream>
pub fn as_ptr(&self) -> *const AVStream
pub fn as_mut_ptr(&mut self) -> *mut AVStream
Sourcepub unsafe fn set_ptr(&mut self, ptr: NonNull<AVStream>)
pub unsafe fn set_ptr(&mut self, ptr: NonNull<AVStream>)
Safety
This function should only be called when the pointer is valid and the data it’s pointing to can be dropped.
pub fn set_avg_frame_rate(&mut self, avg_frame_rate: AVRational)
pub fn set_discard(&mut self, discard: i32)
pub fn set_disposition(&mut self, disposition: c_int)
pub fn set_duration(&mut self, duration: i64)
pub fn set_event_flags(&mut self, event_flags: c_int)
pub fn set_sample_aspect_ratio(&mut self, sample_aspect_ratio: AVRational)
pub fn set_time_base(&mut self, time_base: AVRational)
Sourcepub fn guess_framerate(&self) -> Option<AVRational>
pub fn guess_framerate(&self) -> Option<AVRational>
Guess the frame rate, based on both the container and codec information.
Return None when index is not valid. Some(0/1) if no idea.
Sourcepub fn codecpar(&'stream self) -> AVCodecParametersRef<'stream>
pub fn codecpar(&'stream self) -> AVCodecParametersRef<'stream>
Get codec parameters of current stream.
Sourcepub fn codecpar_mut(&'stream mut self) -> AVCodecParametersMut<'stream>
pub fn codecpar_mut(&'stream mut self) -> AVCodecParametersMut<'stream>
Get mutable reference of codec parameters in current stream.
Sourcepub fn set_codecpar(&mut self, parameters: AVCodecParameters)
pub fn set_codecpar(&mut self, parameters: AVCodecParameters)
Set codecpar of current stream with given parameters.
Sourcepub fn metadata(&'stream self) -> Option<AVDictionaryRef<'stream>>
pub fn metadata(&'stream self) -> Option<AVDictionaryRef<'stream>>
Get metadata of current stream.
Sourcepub fn metadata_mut(&'stream mut self) -> Option<AVDictionaryMut<'stream>>
pub fn metadata_mut(&'stream mut self) -> Option<AVDictionaryMut<'stream>>
Get mutable reference of metadata in current stream.
Sourcepub fn set_metadata(&mut self, dict: Option<AVDictionary>)
pub fn set_metadata(&mut self, dict: Option<AVDictionary>)
Set metadata of current AVStream.