Everything related to libavutil.
Structs
- AVAudio
Fifo - Context for an Audio FIFO Buffer.
- AVBuffer
Ref - AVChannel
Layout - AVChannel
Layout Iter - Iterate over all standard channel layouts.
- AVChannel
Layout Ref - AVComponent
Descriptor - AVDictionary
- AVDictionary
Entry - AVDictionary
Entry Mut - AVDictionary
Entry Ref - AVDictionary
Iter - Iterator over
AVDictionaryby reference. - AVDictionary
Mut - AVDictionary
Ref - AVFrame
- AVFrame
Side Data - AVFrame
Side Data Ref - AVFrame
With Image - It’s a
AVFramebound withAVImage, theAVFramereferences the buffer owned by theAVImage. - AVHW
Device Context - AVHW
Device Type Iter - Iterator over supported device types.
- AVHW
Frames Context - This struct describes a set or pool of “hardware” frames (i.e. those with data not located in normal system memory). All the frames in the pool are assumed to be allocated in the same way and interchangeable.
- AVHW
Frames Context Mut - AVHW
Frames Context Ref - AVImage
- AVMD5
- AVMedia
Type - non exhaustive wrapper of AVMediaType
- AVMem
- AVMmap
- A read-only file buffer, the file is mmaped when available.
- AVPix
FmtDescriptor Ref - Descriptor that unambiguously describes how the bits of a pixel are stored in the up to 4 data planes of an image. It also stores the subsampling factors and number of components.
- AVRational
- Rational number (pair of numerator and denominator).
- AVSamples
- AvVersion
- Version information decoded from
av*_version()
Constants
- FFMPEG_
VERSION - The informative version string of the FFmpeg that ffi bindings were generated against.
- VERSION
- Descriptive semver version of the
libavutilthat ffi bindings were generated against.
Functions
- av_
add_ q - Add two rationals. Returns
b+c. - av_
cmp_ q - Compare two rationals.
- av_d2q
- Convert a double precision floating point number to a rational. In case of infinity, the returned value is expressed as {1, 0} or {-1, 0} depending on the sign.
- av_
div_ q - Divide one rational by another. Returns
b/c. - av_
gcd_ q - Return the best rational so that a and b are multiple of it. If the resulting denominator is larger than max_den, return def.
- av_
image_ ⚠fill_ arrays - Setup the data pointers and linesizes based on the specified image parameters and the provided array.
- av_
inv_ q - Invert a rational. @param q value @return 1 / q
- av_
make_ q - Create an AVRational.
- av_
mul_ q - Multiply two rationals. Returns
b*c. - av_
nearer_ q - Find which of the two rationals is closer to another rational.
- av_q2d
- Convert an AVRational to a
double. @param a AVRational to convert @returnain floating-point form @see av_d2q() - av_
q2intfloat - Convert an AVRational to a IEEE 32-bit float expressed in fixed-point format.
- av_
rescale_ q - Rescale a 64-bit integer by 2 rational numbers.
- av_
rescale_ q_ rnd - Rescale a 64-bit integer by 2 rational numbers with specified rounding.
- av_
rescale_ rnd - Rescale a 64-bit integer with specified rounding.
- av_
sub_ q - Subtract one rational from another. Returns
b-c. - configuration
- Returns the configuration of the
libavutilthat has been linked (whether static or dynamic). - err2str
- Return a description of the AVERROR code errnum.
- get_
bytes_ per_ sample - Return number of bytes per sample, return
Nonewhen sample format is unknown. - get_
media_ type_ string - Return a string describing the media_type enum, NULL if media_type is unknown.
- get_
packed_ sample_ fmt - Get the packed alternative form of the given sample format, return
Noneon error. - get_
pix_ fmt_ name - Return the name of the given pixel format, or
Noneifpix_fmtis not recognized. - get_
planar_ sample_ fmt - Get the planar alternative form of the given sample format. return
Noneon error. - get_
sample_ fmt - Return a sample format corresponding to name, or None on error.
- get_
sample_ fmt_ name - Return the name of given sample_fmt, or
Noneif sample_fmt is not recognized. - hwdevice_
find_ type_ by_ name - Look up an AVHWDeviceType by name.
- hwdevice_
get_ type_ name - Get the string name of an AVHWDeviceType.
- hwdevice_
iterate_ types - Iterate over supported device types.
- license
- Returns the license of the
libavutilthat has been linked (whether static or dynamic). - opt_set⚠
name: the name of the field to setval: if the field is not of a string type, then the given string is parsed. SI postfixes and some named scalars are supported. If the field is of a numeric type, it has to be a numeric or named scalar. Behavior with more than one scalar and +- infix operators is undefined. If the field is of a flags type, it has to be a sequence of numeric scalars or named flags separated by ‘+’ or ‘-’. Prefixing a flag with ‘+’ causes it to be set without affecting the other flags; similarly, ‘-’ unsets a flag. If the field is of a dictionary type, it has to be a ‘:’ separated list of key=value parameters. Values containing ‘:’ special characters must be escaped.search_flags: flags passed toav_opt_find2. I.e. if `AV_OPT_SEARCH_CHILDREN`` is passed here, then the option may be set on a child of obj.- opt_
set_ ⚠bin - Note: if
val.len()exceedsi32::MAX, this function returns [RsmpegError::TryFromIntError]. - opt_
set_ ⚠double - Safety
- opt_
set_ ⚠image_ size - Safety
- opt_
set_ ⚠int - Safety
- opt_
set_ ⚠pixel_ fmt - Safety
- opt_
set_ ⚠q - Safety
- opt_
set_ ⚠sample_ fmt - Safety
- opt_
set_ ⚠video_ rate - Safety
- ra
- return
AVRational: num / den; - sample_
fmt_ is_ planar - Check if the sample format is planar.
- ts2str
- Get a string containing a timestamp representation.
- ts2timestr
- Get a string containing a timestamp time representation.
- version
- Returns the semver version of the
libavutilthat has been linked (whether static or dynamic). - version_
info - Return an informative version string of the FFmpeg that has been linked (whether static or dynamic).
Type Aliases
- AVHW
Device Type - AVMotion
Vector - AVPixel
Format - Pixel format.
- AVRounding
- Rounding methods.
- AVSample
Format - Audio sample formats