#[repr(C)]pub struct SwsContext {Show 21 fields
pub av_class: *const AVClass,
pub opaque: *mut c_void,
pub flags: u32,
pub scaler_params: [f64; 2],
pub threads: i32,
pub dither: u32,
pub alpha_blend: u32,
pub gamma_flag: i32,
pub src_w: i32,
pub src_h: i32,
pub dst_w: i32,
pub dst_h: i32,
pub src_format: i32,
pub dst_format: i32,
pub src_range: i32,
pub dst_range: i32,
pub src_v_chr_pos: i32,
pub src_h_chr_pos: i32,
pub dst_v_chr_pos: i32,
pub dst_h_chr_pos: i32,
pub intent: i32,
}Expand description
Main external API structure. New fields can be added to the end with minor version bumps. Removal, reordering and changes to existing fields require a major version bump. sizeof(SwsContext) is not part of the ABI.
Fields
av_class: *const AVClassopaque: *mut c_voidPrivate data of the user, can be used to carry app specific stuff.
flags: u32Bitmask of SWS_*. See SwsFlags for details.
scaler_params: [f64; 2]Extra parameters for fine-tuning certain scalers.
threads: i32How many threads to use for processing, or 0 for automatic selection.
dither: u32Dither mode.
alpha_blend: u32Alpha blending mode. See SwsAlphaBlend for details.
gamma_flag: i32Use gamma correct scaling.
src_w: i32< Width and height of the source frame
src_h: i32< Width and height of the source frame
dst_w: i32< Width and height of the destination frame
dst_h: i32< Width and height of the destination frame
src_format: i32< Source pixel format
dst_format: i32< Destination pixel format
src_range: i32< Source is full range
dst_range: i32< Destination is full range
src_v_chr_pos: i32< Source vertical chroma position in luma grid / 256
src_h_chr_pos: i32< Source horizontal chroma position
dst_v_chr_pos: i32< Destination vertical chroma position
dst_h_chr_pos: i32< Destination horizontal chroma position
intent: i32Desired ICC intent for color space conversions.